nc-time-axis
============

|Travis|_ |Coveralls|_

Support for netcdftime axis in matplotlib.


See also
--------

* `matplotlib <http://matplotlib.org/>`_
* `netcdftime <https://github.com/Unidata/netcdf4-python/blob/master/netcdftime/netcdftime.py>`_

.. |Travis| image:: https://travis-ci.org/SciTools/nc-time-axis.svg?branch=master
.. _Travis: https://travis-ci.org/SciTools/nc-time-axis

.. |Coveralls| image:: https://coveralls.io/repos/github/SciTools/nc-time-axis/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/github/SciTools/nc-time-axis?branch=master 
